RemoteCommandException (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class RemoteCommandException

    java.lang.Object
      java.lang.Throwable
          java.lang.Exception
              org.openqa.selenium.server.RemoteCommandException

All Implemented Interfaces:
  java.io.Serializable

Direct Known Subclasses:
  WindowClosedException

    public class RemoteCommandException

extends java.lang.Exception

Exception to notify calling methods that an exception occurred when executing the method.

Author:
  Matthew Purland
See Also:
  Serialized Form

Constructor Summary
`RemoteCommandException(java.lang.String message, java.lang.String result)`
`RemoteCommandException(java.lang.String message, java.lang.String result, java.lang.Throwable throwable)`

Method Summary
`java.lang.String` | `getResult()` Get the result of the remote command that caused the exception.

Methods inherited from class java.lang.Throwable
`fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

Constructor Detail

### RemoteCommandException

    public RemoteCommandException(java.lang.String message,
                                  java.lang.String result)

### RemoteCommandException

    public RemoteCommandException(java.lang.String message,
                                  java.lang.String result,
                                  java.lang.Throwable throwable)

Method Detail

### getResult

    public java.lang.String getResult()

  Get the result of the remote command that caused the exception.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.